class puppet_enterprise::console::config(
  $ca_host,
  $master_host,
  $puppetdb_host,
  $console_server_certname,
  $console_client_certname,
  $delayed_job_workers,
  $apache_limit_request_line = 65536,
  $localcacert               = $puppet_enterprise::params::localcacert,
  $hostcrl                   = $puppet_enterprise::params::hostcrl,
  $puppetdb_port             = $puppet_enterprise::params::puppetdb_ssl_listen_port,
  $listen_address            = $puppet_enterprise::params::plaintext_address,
  $listen_port               = $puppet_enterprise::params::dashboard_listen_port,
  $ssl_cipher_suite          = 'ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-DSS-AES128-SHA256:DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:ECDHE-RSA-DES-CBC3-SHA:ECDHE-ECDSA-DES-CBC3-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA256:AES256-SHA256:AES128-SHA:AES256-SHA:AES:CAMELLIA:DES-CBC3-SHA:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!aECDH:!EDH-DSS-DES-CBC3-SHA:!EDH-RSA-DES-CBC3-SHA:!KRB5-DES-CBC3-SHA',
  $ssl_listen_address        = $puppet_enterprise::params::ssl_address,
  $ssl_listen_port           = $puppet_enterprise::params::dashboard_ssl_listen_port,
  $classifier_host           = $::clientcert,
  $classifier_port           = $puppet_enterprise::params::console_services_api_ssl_listen_port,
  $classifier_url_prefix     = $puppet_enterprise::params::classifier_url_prefix,
  $lm_discovery_timeout      = undef,
  $lm_inventory_retries      = undef,
  $secret_token              = '',
  $certname                  = $::clientcert,
  $disable_live_management   = true,
  $dhparam_file              = '/opt/puppet/share/puppet-dashboard/certs/dhparam_puppetdashboard.pem' ,
  $dhparam_cert_group        = 'puppet-dashboard',
  $dhparam_cert_mode         = '0644',
  $dhparam_cert_owner        = 'puppet-dashboard',
) inherits puppet_enterprise::params {

  File {
    notify => Service['pe-httpd'],
  }

  $config_dir = '/etc/puppetlabs/puppet-dashboard'

  # Uses
  # $pool_size
  $pool_size = $puppet_enterprise::params::passenger_pool_size
  file { '/etc/puppetlabs/httpd/conf.d/passenger-extra.conf':
    content => template('puppet_enterprise/console/passenger-extra.conf.erb'),
    replace => false,
  }

  # Uses
  # $apache_limit_request_line
  file { '/etc/puppetlabs/httpd/console_apps.d/console-virtual-host.def':
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0644',
    content => template('puppet_enterprise/console/virtual-host.def.erb'),
  }

  $default_dhparam_file = '/opt/puppet/share/puppet-dashboard/certs/dhparam_puppetdashboard.pem'
  file { $default_dhparam_file:
    ensure => file,
    source => 'puppet:///modules/puppet_enterprise/console/dhparam_puppetdashboard.pem',
    owner  => $dhparam_cert_owner,
    group  => $dhparam_cert_group,
    mode   => $dhparam_cert_mode,
  }

  $dhparam_cert_target = "/opt/puppet/share/puppet-dashboard/certs/dhparam_puppetdashboard_cert.pem"
  $dhparam_ssl_cert = "/etc/puppetlabs/puppet/ssl/certs/${console_server_certname}.pem"

  puppet_enterprise::console::dhparam { $dhparam_file:
    dhparam_cert_target  => $dhparam_cert_target,
    ssl_certificate_file => $dhparam_ssl_cert ,
    dhparam_cert_group   => $dhparam_cert_group,
    dhparam_cert_mode    => $dhparam_cert_mode,
    dhparam_cert_owner   => $dhparam_cert_owner,
    require              => File['/opt/puppet/share/puppet-dashboard/certs', $default_dhparam_file],
  }

  # Uses
  # $console_server_certname
  # $dhparam_file
  # $localcacert
  # $hostcrl
  # $listen_address
  # $listen_port
  # $ssl_listen_address
  # $ssl_listen_port
  # $lm_discovery_timeout
  # $lm_inventory_retries
  file { '/etc/puppetlabs/httpd/conf.d/puppetdashboard.conf':
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0644',
    content => template('puppet_enterprise/console/puppetdashboard.conf.erb'),
    require => File['/etc/puppetlabs/httpd/console_apps.d/console-virtual-host.def'],
  }

  $cert_whitelist_path = '/etc/puppetlabs/puppet-dashboard/dashboard-certificate-whitelist'
  file { $cert_whitelist_path:
    ensure => file,
    group  => 'puppet-dashboard',
    owner  => 'puppet-dashboard',
    mode   => '0600',
  }

  unless pe_empty($secret_token) {
    # Uses
    # $ca_host
    # $cert_whitelist_path
    # $master_host
    # $secret_token
    # $console_client_certname
    # $localcacert
    # $hostcrl
    # $classifier_host
    # $classifier_port
    # $classifier_url_prefix
    # $certname
    # $ssl_listen_port
    # $disable_live_management
    file {  "${config_dir}/settings.yml":
      owner   => 'puppet-dashboard',
      group   => 'puppet-dashboard',
      mode    => '0640',
      content => template('puppet_enterprise/console/settings.yml.erb'),
    }
  }

  # Uses
  # $console_client_certname
  # $localcacert
  file { '/opt/puppet/share/console/applications/licenses/config.yml':
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0644',
    content => template('puppet_enterprise/console/licenses_config.yml.erb'),
  }

  # Uses
  # $console_client_certname
  # $puppetdb
  # $puppetdb_port
  # $localcacert
  file { '/opt/puppet/share/event-inspector/config/config.yml':
    owner   => 'pe-auth',
    group   => 'puppet-dashboard',
    mode    => '0640',
    content => template('puppet_enterprise/console/event_inspector_config.yml.erb'),
  }

  # Uses
  # $delayed_job_workers
  file { "${puppet_enterprise::params::defaults_dir}/pe-puppet-dashboard-workers":
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0644',
    content => template('puppet_enterprise/console/pe-puppet-dashboard-workers.default.erb'),
    notify  => Service['pe-puppet-dashboard-workers'],
  }

  file { '/var/log/pe-puppet-dashboard':
    ensure  => directory,
    owner   => 'puppet-dashboard',
    group   => 'puppet-dashboard',
    mode    => '0644',
    recurse => true,
    notify  => [],
  }

  file { '/var/log/pe-puppet-dashboard/failed_reports':
    ensure  => directory,
    mode    => '0600',
    recurse => true,
    notify  => [],
  }

  file { '/var/log/pe-puppet-dashboard/delayed_job.log':
    ensure => present,
    owner  => 'puppet-dashboard',
    group  => 'puppet-dashboard',
    mode   => '0644',
    notify => [],
  }

  file { ['/opt/puppet/share/live-management/config.ru', '/opt/puppet/share/puppet-dashboard/config.ru']: }
}
